@@ -1,6 +1,6 @@
 (*---------------------------------------------------------------------------
    Copyright (c) 2015 The mtime programmers. All rights reserved.
-   Distributed under the ISC license, see terms at the end of the file.
+   SPDX-License-Identifier: ISC
   ---------------------------------------------------------------------------*)
 
 (** Monotonic time values.
@@ -55,6 +55,12 @@ module Span : sig
   val compare : span -> span -> int
   (** [compare span span'] orders spans by increasing duration. *)
 
+  val is_shorter : span -> than:span -> bool
+  (** [is_shorter span ~than] is [true] iff [span] lasts less than [than]. *)
+
+  val is_longer : span -> than:span -> bool
+  (** [is_longer span ~than] is [true] iff [span] lasts more than [than]. *)
+
   (** {1:arith Arithmetic} *)
 
   val add : span -> span -> span
@@ -220,19 +226,3 @@ val pp : Format.formatter -> t -> unit
 val dump : Format.formatter -> t -> unit
 (** [dump ppf t] formats an unspecified raw representation of [t] on
     [ppf]. *)
-
-(*---------------------------------------------------------------------------
-   Copyright (c) 2015 The mtime programmers
-
-   Permission to use, copy, modify, and/or distribute this software for any
-   purpose with or without fee is hereby granted, provided that the above
-   copyright notice and this permission notice appear in all copies.
-
-   THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES
-   WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
-   MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR
-   ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
-   WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
-   ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
-   OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
-  ---------------------------------------------------------------------------*)
